# filehandlers

![Version Badge](https://img.shields.io/pypi/v/filehandlers.svg?color=purple&logo=python&style=for-the-badge)
![CI Build Badge](https://img.shields.io/cirrus/github/RDIL/filehandlers.svg?logo=cirrus-ci&style=for-the-badge)

Package containing code to help in working with files.

## Documentation

We have documentation located [here](https://filehandlers.rdil.rocks).
